@@ -174,6 +174,7 @@ void CAccountView::OnSelchangeAccount()
 	CFolderView *fv = mf->m_pTreeV;
 	CSummaryView *sv = mf->m_pListV;
 	CTextView *tv = mf->m_pTextV;
+	CHeaderView *hv = mf->m_pHeadV;
 
 	fv->ConstructTree(account);
 
@@ -190,6 +191,7 @@ void CAccountView::OnSelchangeAccount()
 	// if multipartview is showing, hide.
 	sv->Clear();
 	tv->Clear();
+	hv->Clear();
 
 	// change document name to current mail box name
     CString title;
