@@ -32,6 +32,8 @@ public:
 
 // Iy[V
 public:
+	void SetAccountPopPass(CString account, CString pass);
+	CString GetAccountPopPass(CString account);
 	CString GetFirstAccountName();
 	void SetButtonStatus(char *account, int id, BOOL status);
 	BOOL GetButtonStatus(char *account, int id);
@@ -53,6 +55,7 @@ public:
 		BOOL button_retrieve;
 		CString account_name;
 		CString status_text;
+		CString pop_pass;
 		int status_pgbar_upper;
 		int status_pgbar_current;
 	};
