@@ -232,7 +232,7 @@ BOOL CDraftFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 	this->m_wndSplit.SetStaticBorder(TRUE);
 	this->m_wndSplit1.CreateStatic(&m_wndSplit, 2, 1, WS_CHILD|WS_VISIBLE|WS_BORDER, m_wndSplit.IdFromRowCol(0,0));
 
-	this->m_wndSplit1.CreateView(0, 0, RUNTIME_CLASS(CAddressView), CSize(0,HT_HEAD), pContext);
+	this->m_wndSplit1.CreateView(0, 0, RUNTIME_CLASS(CAddressView), CSize(0,DEF_ADDRESS_HEIGHT), pContext);
 	this->m_wndSplit1.CreateView(1, 0, RUNTIME_CLASS(CMailEditView), CSize(0, 0), pContext);
 	this->m_wndSplit1.NoBorder();
 	this->m_wndSplit1.SetStaticBorder(TRUE);
