@@ -10,6 +10,7 @@
 #include "Pochy.h"
 #include "MainFrm.h"
 #include "SummaryView.h"
+#include "HeaderView.h"
 #include "FolderView.h"
 #include "PochyDoc.h"
 #include "Retrieve.h"
@@ -24,6 +25,7 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 #define TREEVIEW_FILENAME _T("\\skin\\treeview.bmp")
+#define TREEVIEW_BACKGROUND_FILENAME _T("\\skin\\FolderViewBk.bmp")
 
 /////////////////////////////////////////////////////////////////////////////
 // CFolderView
@@ -39,7 +41,7 @@ CFolderView::~CFolderView()
 {
 }
 
-BEGIN_MESSAGE_MAP(CFolderView, CTreeView)
+BEGIN_MESSAGE_MAP(CFolderView, CBitmapTreeView)
 	//{{AFX_MSG_MAP(CFolderView)
 	ON_NOTIFY_REFLECT(TVN_SELCHANGED, OnSelchanged)
 	ON_NOTIFY_REFLECT(TVN_ITEMEXPANDED, OnItemexpanded)
@@ -166,6 +168,10 @@ void CFolderView::OnInitialUpdate()
 	// c[̍ŏ̃ACeI
 	HTREEITEM ti = tc.GetChildItem(tc.GetRootItem());
 	tc.SelectItem(ti);
+
+	// tH_[r[̔wi摜ݒ
+	CString strBackgroundFilePath = app->m_app_path + TREEVIEW_BACKGROUND_FILENAME;
+	SetBkImage(strBackgroundFilePath);
 }
 
 void CFolderView::ConstructTree(CString account)
@@ -194,6 +200,7 @@ void CFolderView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult)
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CSummaryView *sv = mf->m_pListV;
 	CTextView *tv = mf->m_pTextV;
+	CHeaderView *hv = mf->m_pHeadV;
 
 	HTREEITEM ti = tc.GetSelectedItem();
 	CString current_account;
@@ -213,17 +220,16 @@ void CFolderView::OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult)
 	// multipartviewBĂȂΉB
 	mf->HideMultiPartView(TRUE);
 
-	// display empty on textview
+	// clear away
 	tv->Clear();
+	hv->Clear();
 
 	// ̃hLgJg[{bNXɂ
-//	GetDocument()->SetTitle(mf->m_pAcntV->GetCurrentAccountName());
     CString title;
     CString account = mf->m_pAcntV->GetCurrentAccountName();
     title.Format("%s - %s", account, "pochy");
     mf->SetWindowText(title);
 
-
 	*pResult = 0;
 }
 
@@ -256,7 +262,6 @@ void CFolderView::OnItemexpanded(NMHDR* pNMHDR, LRESULT* pResult)
 {
 	HTREEITEM ti;
 	CString path;
-//	CTreeCtrl& treeCtrl = GetTreeCtrl();
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	NM_TREEVIEW* pNMTreeView = (NM_TREEVIEW*)pNMHDR;
 
