@@ -7,6 +7,7 @@
 // FolderView.h : wb_[ t@C
 //
 #include <afxcview.h>
+#include "BitmapTreeView.h"
 
 #define FV_INBOX	(1)
 #define FV_OUTBOX	(2)
@@ -18,7 +19,7 @@
 /////////////////////////////////////////////////////////////////////////////
 // CFolderView r[
 
-class CFolderView : public CTreeView
+class CFolderView : public CBitmapTreeView
 {
 protected:
 	CFolderView();           // IɎgpveNg RXgN^
