@@ -95,54 +95,54 @@ void CHeaderInfo::Analyze()
 		field = m_decoded_header[i].Left(pos);
 		regcomp(&reg, field, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
 
-		if(!regexec(&reg, "^subject:", 0, NULL, 0)){
+		if(!regexec(&reg, "subject", 0, NULL, 0)){
 			regfree(&reg);
 			m_subject = m_decoded_header[i].Mid(strlen("Subject:"));
 			g_cstr_chop(m_subject);
 			continue;
 		}
-		if(!regexec(&reg, "^cc:", 0, NULL, 0)){
+		if(!regexec(&reg, "cc", 0, NULL, 0)){
 			regfree(&reg);
 			m_cc = m_decoded_header[i].Mid(strlen("cc:"));
 			g_cstr_chop(m_cc);
 			continue;
 		}
-		if(!regexec(&reg, "^bcc:", 0, NULL, 0)){
+		if(!regexec(&reg, "bcc", 0, NULL, 0)){
 			regfree(&reg);
 			m_bcc = m_decoded_header[i].Mid(strlen("bcc:"));
 			g_cstr_chop(m_bcc);
 			continue;
 		}
-		if(!regexec(&reg, "^from:", 0, NULL, 0)){
+		if(!regexec(&reg, "from", 0, NULL, 0)){
 			regfree(&reg);
 			m_from = m_decoded_header[i].Mid(strlen("from:"));
 			g_cstr_chop(m_from);
 			continue;
 		}
-		if(!regexec(&reg, "^to:", 0, NULL, 0)){
+		if(!regexec(&reg, "to", 0, NULL, 0)){
 			regfree(&reg);
 			m_to = m_decoded_header[i].Mid(strlen("to:"));
 			g_cstr_chop(m_to);
 			continue;
 		}
-		if(!regexec(&reg, "^x-mailer:", 0, NULL, 0)){
+		if(!regexec(&reg, "x-mailer", 0, NULL, 0)){
 			regfree(&reg);
 			m_xmailer = m_decoded_header[i].Mid(strlen("x-mailer:"));
 			g_cstr_chop(m_xmailer);
 			continue;
 		}
-		if(!regexec(&reg, "^reply-to:", 0, NULL, 0)){
+		if(!regexec(&reg, "reply-to", 0, NULL, 0)){
 			regfree(&reg);
 			m_replyto = m_decoded_header[i].Mid(strlen("reply-to:"));
 			g_cstr_chop(m_replyto);
 			continue;
 		}
-		if(!regexec(&reg, "^date:", 0, NULL, 0)){
+		if(!regexec(&reg, "date", 0, NULL, 0)){
 			regfree(&reg);
 			m_date = ReformDate(m_decoded_header[i]);
 			continue;
 		}
-		if(!regexec(&reg, "^content-transfer-encoding:", 0, NULL, 0)){
+		if(!regexec(&reg, "content-transfer-encoding", 0, NULL, 0)){
 			regfree(&reg);
 			CString cte;
 			m_cte = m_decoded_header[i];
@@ -163,26 +163,26 @@ void CHeaderInfo::Analyze()
 				m_enc = QUOTED_PRINTABLE;
 			continue;
 		}
-		if(!regexec(&reg, "^message-id:", 0, NULL, 0)){
+		if(!regexec(&reg, "message-id", 0, NULL, 0)){
 			regfree(&reg);
 			m_msg_id = m_decoded_header[i].Mid(strlen("Message-ID:"));
 			g_cstr_chop(m_msg_id);
 			continue;
 		}
-		if(!regexec(&reg, "^in-reply-to:", 0, NULL, 0)){
+		if(!regexec(&reg, "in-reply-to", 0, NULL, 0)){
 			regfree(&reg);
 			m_in_reply_to = m_decoded_header[i].Mid(strlen("In-Reply-To:"));
 			g_cstr_chop(m_in_reply_to);
 			continue;
 		}
-		if(!regexec(&reg, "^content-type:", 0, NULL, 0)){
+		if(!regexec(&reg, "content-type", 0, NULL, 0)){
 			regfree(&reg);
 			m_ct = m_decoded_header[i];
 			g_cstr_chop(m_ct);
 			AnalyzeCT();
 			continue;
 		}
-		if(!regexec(&reg, "^content-disposition:", 0, NULL, 0)){
+		if(!regexec(&reg, "content-disposition", 0, NULL, 0)){
 			regfree(&reg);
 			m_cd = m_decoded_header[i];
 			g_cstr_chop(m_cd);
