@@ -280,7 +280,7 @@ void CMailEditView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 
 void CMailEditView::GetText(CString &buf)
 {
-	buf.Empty();
+/*	buf.Empty();
 	CRichEditCtrl &r = GetRichEditCtrl();
 	CHARRANGE cr;
 	char *tmp;
@@ -291,7 +291,9 @@ void CMailEditView::GetText(CString &buf)
 	r.GetSelText(tmp);
 	r.SetSel(cr);
 	buf=tmp;
-	delete [] tmp;
+	delete [] tmp;*/
+	buf.Empty();
+	this->GetRichEditCtrl().GetWindowText(buf);
 }
 
 void CMailEditView::Font()
