@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2002-2003 chik, s.hiranaka
  * 2003-10-26 Some modification is done for task tray icon and the animation by minamina.
+ * 2003-11-05 Some modification is done for rearrangeable summary column by minamina.
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -12,6 +13,7 @@
 #include "FolderView.h"
 #include "AccountView.h"
 #include "TextView.h"
+#include "HeaderView.h"
 #include "Sock.h"
 #include "CodeConvert.h"
 #include "FetchMail.h"
@@ -232,43 +234,46 @@ BOOL CMainFrame::OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext)
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	int x, y;
 
-	lpcs->cx;
-	lpcs->cy;
+	// create each pane
+	m_split_left_right.CreateStatic(this,1,2);
+	m_split_multi_others.CreateStatic(&m_split_left_right,2,1,WS_CHILD|WS_VISIBLE,m_split_left_right.IdFromRowCol(0,1));
+	m_split_summary_others.CreateStatic(&m_split_multi_others,2,1,WS_CHILD|WS_VISIBLE,m_split_multi_others.IdFromRowCol(0,0));
+	m_split_header_text.CreateStatic(&m_split_summary_others,2,1,WS_CHILD|WS_VISIBLE,m_split_summary_others.IdFromRowCol(1,0));
+	m_split_account_folder.CreateStatic(&m_split_left_right,2,1,WS_CHILD|WS_VISIBLE,m_split_left_right.IdFromRowCol(0,0));
+	m_split_account_folder.CreateView(0,0,RUNTIME_CLASS(CAccountView),CSize(0, 0),pContext);
+	m_split_account_folder.CreateView(1,0,RUNTIME_CLASS(CFolderView),CSize(0, 0),pContext);
+	m_split_account_folder.NoBorder();
+	m_split_account_folder.SetStaticBorder(TRUE);
+	m_split_multi_others.CreateView(1,0,RUNTIME_CLASS(CMultiPartView),CSize(0, 0),pContext);
+	m_split_summary_others.CreateView(0,0,RUNTIME_CLASS(CSummaryView),CSize(0, 0),pContext);
+	m_split_header_text.CreateView(0,0,RUNTIME_CLASS(CHeaderView),CSize(0, 0),pContext);
+	m_split_header_text.CreateView(1,0,RUNTIME_CLASS(CTextView),CSize(0, 0),pContext);
+	m_split_header_text.NoBorder();
 
-	// EBhE쐬܂
-	m_wndSplitV.CreateStatic(this,1,2);
-	m_wndSplitH.CreateStatic(&m_wndSplitV,2,1,WS_CHILD|WS_VISIBLE,m_wndSplitV.IdFromRowCol(0,1));
-	m_wndSplitT.CreateStatic(&m_wndSplitH,2,1,WS_CHILD|WS_VISIBLE,m_wndSplitH.IdFromRowCol(0,0));
-	m_wndSplitT2.CreateStatic(&m_wndSplitV,2,1,WS_CHILD|WS_VISIBLE,m_wndSplitV.IdFromRowCol(0,0));
-
-	m_wndSplitT2.CreateView(0,0,RUNTIME_CLASS(CAccountView),CSize(0, 0),pContext);
-	m_wndSplitT2.CreateView(1,0,RUNTIME_CLASS(CFolderView),CSize(0, 0),pContext);
-	m_wndSplitT2.NoBorder();
-	m_wndSplitT2.SetStaticBorder(TRUE);
-	m_wndSplitH.CreateView(1,0,RUNTIME_CLASS(CMultiPartView),CSize(0, 0),pContext);
-	m_wndSplitT.CreateView(0,0,RUNTIME_CLASS(CSummaryView),CSize(0, 0),pContext);
-	m_wndSplitT.CreateView(1,0,RUNTIME_CLASS(CTextView),CSize(0, 0),pContext);
-
-	/* ꂼVIEWւ̃|C^ۑĂ
-       VIEWmł̎QƂKvɂȂꍇ
-	   GetParentFrameCMainFramẽ|C^擾āÃołm_pTVAm_pLV擾 */
-	m_pListV = (CSummaryView*)m_wndSplitT.GetPane(0, 0);
-	m_pAcntV = (CAccountView*)m_wndSplitT2.GetPane(0, 0);
-	m_pTreeV = (CFolderView*)m_wndSplitT2.GetPane(1, 0);
-	m_pTextV = (CTextView*)m_wndSplitT.GetPane(1, 0);
-	m_pMultiV = (CMultiPartView*)m_wndSplitH.GetPane(1, 0);
+	// save pointer of each pane
+	m_pAcntV = (CAccountView*)m_split_account_folder.GetPane(0, 0);
+	m_pTreeV = (CFolderView*)m_split_account_folder.GetPane(1, 0);
+	m_pListV = (CSummaryView*)m_split_summary_others.GetPane(0, 0);
+	m_pHeadV = (CHeaderView*)m_split_header_text.GetPane(0, 0);
+	m_pTextV = (CTextView*)m_split_header_text.GetPane(1, 0);
+	m_pMultiV = (CMultiPartView*)m_split_multi_others.GetPane(1, 0);
 
+	// adjust each pane size
 	x = app->GetProfileInt("SplitWnd", "LeftPaneWidth", 180);
-	m_wndSplitV.SetColumnInfo(0, x, 10);
-	m_wndSplitT2.SetRowInfo(0, 20, 10);
+	m_split_left_right.SetColumnInfo(0, x, 10);
+	m_split_account_folder.SetRowInfo(0, 20, 10);
 
 	y = app->GetProfileInt("SplitWnd", "SummaryViewHeight", 300);
-	m_wndSplitT.SetRowInfo(0, y, 10);
+	m_split_summary_others.SetRowInfo(0, y, 10);
 
-	y = app->GetProfileInt("SplitWnd", "TextViewHeight", 300);
-	m_wndSplitT.SetRowInfo(1, y, 10);
+	y = app->GetProfileInt("SplitWnd", "HeaderViewHeight", DEF_HEADER_HEIGHT);
+	m_split_header_text.SetRowInfo(0, y, 10);
 
+	// hide multipartview
 	this->HideMultiPartView(TRUE);
+	if(!app->GetProfileInt("Customize", "HeaderView", 1)){
+		this->HideHeaderView(TRUE);
+	}
 
 	m_flag = TRUE;
 	return TRUE;
@@ -336,7 +341,7 @@ void CMainFrame::OnGpgDec()
 	CString header;
 	CString body;
 
-	// pXt[Y͂Ă炤
+	// input pass phrase
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	if(app->m_gpg_passphrase.IsEmpty()){
 		CPassPhraseDlg pf;
@@ -348,7 +353,7 @@ void CMainFrame::OnGpgDec()
 	}
 	CString pass = app->m_gpg_passphrase;
 
-	// fR[h
+	// decoding
 	buf = gpg.Decode(m_pTextV->GetCurrentPath(), pass);
 	if(buf.IsEmpty()){
 		app->m_gpg_passphrase.Empty();
@@ -359,7 +364,7 @@ void CMainFrame::OnGpgDec()
 	m_pTextV->m_md.m_hi.GetAllUnDecoded(old_header);
 	m_pTextV->m_md.m_hi.RemoveFoldingWhiteSpace(&old_header);
 
-	if(m_pTextV->IsPgpMime()){ // pgp/mimȅꍇ
+	if(m_pTextV->IsPgpMime()){ // in case of pgp/mime
 		CMimeDecode md;
 		md.DoIt2(buf);
 		CStringArray new_header;
@@ -370,7 +375,7 @@ void CMainFrame::OnGpgDec()
 		CString content_transfer_encoding;
 		CString content_disposition;
 
-		// Íꂽ͓canonical mimeƊmimeƂ̐Ƃ
+		// rearrange for connonical mime in pgp/mime
 		int i=0;
 		while(i < new_header.GetSize()){
 			if(0 == new_header.GetAt(i).Find("Content-Type"))
@@ -416,7 +421,7 @@ void CMainFrame::OnGpgDec()
 
 		body = buf.Mid(buf.Find("\r\n\r\n")+4);
 	}else{
-		body = buf; // ׂɓ\tĂꍇ
+		body = buf; // in case of none pgp/mime, may be encoded word is directly put into mail body
 	}
 	g_cstra2cstr(old_header, header, g_cstra_getsize(old_header));
 	header.TrimRight();
@@ -452,16 +457,16 @@ void CMainFrame::OnDestroy()
 	WINDOWPLACEMENT wndPlace;
 	CString num;
 
-	// EBhËʒu擾
+	// getting placement of main window
 	GetWindowPlacement(&wndPlace);
 
-	// EBhËʒuinit@Cɕۑ
+	// saving placemant of main window into ini file 
 	app->WriteProfileInt("WndPlace", "Left", wndPlace.rcNormalPosition.left);
 	app->WriteProfileInt("WndPlace", "Top", wndPlace.rcNormalPosition.top);
 	app->WriteProfileInt("WndPlace", "Right", wndPlace.rcNormalPosition.right);
 	app->WriteProfileInt("WndPlace", "Bottom", wndPlace.rcNormalPosition.bottom);
 
-	// EBhȄԂinit@C֕ۑiő剻AACRAȊOj
+	// saving status of window into ini file (maximize, iconize, others)
 	if(this->IsZoomed()) 
 		app->WriteProfileInt("WndPlace", "Zoom", 1);
 	else if(this->IsIconic()) 
@@ -469,25 +474,32 @@ void CMainFrame::OnDestroy()
 	else
 		app->WriteProfileInt("WndPlace", "Zoom", 0);
 
-	// T}r[̃J̕init@C֕ۑ
+	// saving width of column in summaryview into ini file
 	for(int i = 0; i < 5; i++){
 		num.Format("%d", i);
 		app->WriteProfileInt("SummaryViewColumn", num.GetBuffer(0), m_pListV->GetListCtrl().GetColumnWidth(i));
 	}
 
-	// multipartview̃J̕init@C֕ۑ
+	// saving order of column in summaryview into ini file
+	m_pListV->WriteIniColumnOrder();
+
+	// saving width of column in multipartview into ini file
 	for(i = 0; i < 3; i++){
 		num.Format("%d", i);
 		app->WriteProfileInt("MultiPartViewColumn", num.GetBuffer(0), m_pMultiV->GetListCtrl().GetColumnWidth(i));
 	}
 
-	// eXvbgEBhẼTCYinit@C֕ۑ
+	// saving size of each splited pane into ini file
 	int current;
 	int max;
-	m_wndSplitV.GetColumnInfo(0, current, max);
+	m_split_left_right.GetColumnInfo(0, current, max);
 	app->WriteProfileInt("SplitWnd", "LeftPaneWidth", current);
-	m_wndSplitT.GetRowInfo(0, current, max);
+	m_split_summary_others.GetRowInfo(0, current, max);
 	app->WriteProfileInt("SplitWnd", "SummaryViewHeight", current);
+	if(app->GetProfileInt("Customize", "HeaderView", 1)){
+		m_split_header_text.GetRowInfo(0, current, max);
+		app->WriteProfileInt("SplitWnd", "HeaderViewHeight", current);
+	}
 /*
 typedef struct tagLOGFONT { // lf  
    LONG lfHeight; 
@@ -765,8 +777,7 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 	UINT id;
 
 	// Switch on button command id's
-	switch (pnmtb->iItem)
-	{
+	switch (pnmtb->iItem){
 	case ID_REPLY:
 		id = IDR_MAINFRAME_POPUP_REPLY;
 		break;
@@ -803,28 +814,28 @@ void CMainFrame::OnReplyQuotation()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 
-	// Ƃ肠
+	// initialyze
 	app->m_me.Initialize();
 
-	// to̐ݒireply-toꍇ́Areply-toD
+	// setting to, if reply-to exist, use reply-to address as to address
 	if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
 		app->m_me.SetTo(m_pTextV->GetCurrentFrom());
 	}else{
 		app->m_me.SetTo(m_pTextV->GetCurrentReplyTo());
 	}
 
-	// cc̐ݒ
+	// setting cc
 	if(!m_pTextV->GetCurrentCc().IsEmpty())
 		app->m_me.SetCc(m_pTextV->GetCurrentCc());
 
-	// from̐ݒ
+	// setting from
 	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
 	CString address;
 	GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 	address.ReleaseBuffer();
 	app->m_me.SetFrom(address);
 
-	// subject̐ݒ
+	// setting subject
 	if(m_pTextV->GetCurrentSubject().Find("Re:") == 0 || m_pTextV->GetCurrentSubject().Find("RE:") == 0){
 		app->m_me.SetSubject(m_pTextV->GetCurrentSubject());
 	}else{
@@ -857,20 +868,19 @@ void CMainFrame::OnReplyQuotation()
 	// setting references
 	app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
 
-
-	// {Ɉpݒ
+	// setting quotation
 	CString body = m_pTextV->GetCurrentBody();
 	body.Replace("\r\n","\r\n> ");
 	body = "> "+body+"\r\n";
 
-	// 
+	// signature
 	CString signature;
 	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
 
-	// {ݒ
+	// setting mail body
 	app->m_me.AddText(body+"\r\n"+signature);
 
-	// htgt[쐬
+	// create draft frame
 	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
 }
 
@@ -878,16 +888,16 @@ void CMainFrame::OnReplyNoQuotation()
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 
-	// mimeencodeNXȍ
+	// initialyze mimeencode class member
 	app->m_me.Initialize();
 
-	// To ̐ݒ
+	// To
 	if(!m_pTextV->GetCurrentReplyTo().IsEmpty())
 		app->m_me.SetTo(m_pTextV->GetCurrentReplyTo());
 	else
 		app->m_me.SetTo(m_pTextV->GetCurrentFrom());
 
-	// From ̐ݒ
+	// From
 	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
 	CString address;
 	GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
@@ -895,7 +905,6 @@ void CMainFrame::OnReplyNoQuotation()
 	app->m_me.SetFrom(address);
 
 	// setting "cc" field
-	// cc̐ݒ
 	CString cc;
 	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 	cc.ReleaseBuffer();
@@ -958,24 +967,24 @@ void CMainFrame::ReArrangeSplit()
 	int bar_horizonal = 0; // Ƃ肠0ɂƂ̂ŁAmulti_heightbar̕l^Kv
 
 	// summaryview textview multipartview 킹
-	m_wndSplitV.GetPane(0,1)->GetClientRect(&rect);
+	m_split_left_right.GetPane(0,1)->GetClientRect(&rect);
 	rect.NormalizeRect();
 	int height = rect.Height();
 	rect.SetRectEmpty();
 
-	// multipartview̍HT_MULTI_HEIGHTɂȂ悤ɐݒ
-	m_wndSplitH.SetRowInfo(0, height-(HT_MULTI_HEIGHT+bar_horizonal), 0);
-	m_wndSplitH.SetRowInfo(1, HT_MULTI_HEIGHT, 0);
-	m_wndSplitH.RecalcLayout();
+	// multipartview̍DEF_MULTI_HEIGHTɂȂ悤ɐݒ
+	m_split_multi_others.SetRowInfo(0, height-(DEF_MULTI_HEIGHT+bar_horizonal), 0);
+	m_split_multi_others.SetRowInfo(1, DEF_MULTI_HEIGHT, 0);
+	m_split_multi_others.RecalcLayout();
 }
 
 void CMainFrame::HideMultiPartView(BOOL b)
 {
 	if(b && m_multipart_hide == FALSE){
-		m_wndSplitH.HideRow(1);
+		m_split_multi_others.HideRow(1);
 		m_multipart_hide = TRUE;
 	}else if(!b && m_multipart_hide == TRUE){
-		m_wndSplitH.ShowRow();
+		m_split_multi_others.ShowRow();
 		m_multipart_hide = FALSE;
 	}
 }
@@ -1364,3 +1373,12 @@ void CMainFrame::StopTaskTrayAnimation()
 		}
 	}
 }
+
+void CMainFrame::HideHeaderView(BOOL b)
+{
+	if(b){
+		m_split_header_text.HideRow(0);
+	}else{
+		m_split_header_text.ShowRow();
+	}
+}
