@@ -7,7 +7,6 @@
 #include "Pochy.h"
 #include "MainFrm.h"
 #include "DraftFrame.h"
-//#include "Sock.h"
 #include "Smtp.h"
 #include "CodeConvert.h"
 #include "sendmail.h"
@@ -23,8 +22,6 @@
 			throw mes;\
 		if(buf.Find("250") != 0 && buf.Find("354") != 0 && buf.Find("221") != 0)\
 			throw buf.GetBuffer(0);\
-		g_log("log-sendmail", command);\
-		g_log("log-sendmail", buf);\
 		df->m_send_dlg->m_status.SetWindowText(buf);\
 		buf.Empty()
 
@@ -49,10 +46,10 @@ UINT SendMail(LPVOID pParam)
 
 	mf->StartTaskTrayAnimation();
 
-	// init@Ĉ߂̏
+	// prepare for ini file
 	CString path = app->m_app_path + "\\" + df->m_account + "\\account.ini";
 
-	// header̊mF
+	// confirmation of header
 	if(df->m_me.GetTo().IsEmpty()){
 		df->MessageBox("To: tB[hł", df->m_account+" - header error");
 		df->m_send_dlg->EndDialog(0);
@@ -70,7 +67,7 @@ UINT SendMail(LPVOID pParam)
 		return FALSE;
 	}
 
-	// pop before smtpǂ
+	// pop before smtp
 	pop_before_smtp = GetPrivateProfileInt("smtp", "pop_before_smtp", 0, path);
 	if(pop_before_smtp){
 		try{
@@ -167,7 +164,7 @@ UINT SendMail(LPVOID pParam)
 		}
 		catch(char *errorstr){
 			send(PopSocket.m_sock, "quit\r\n", strlen("quit\r\n"), 0);
-			// socket
+			// close socket
 			PopSocket.DisConnect();
 			if(strlen(errorstr)){
 				df->MessageBox(errorstr, df->m_account+" - pop before smtp error");
@@ -178,19 +175,17 @@ UINT SendMail(LPVOID pParam)
 			mf->StopTaskTrayAnimation();
 			return FALSE;
 		}
-		// pop before smtp @\܂łɎԂ̂ŁAÔ
-//		Sleep(10000);
 	}
 
 	try{
-		// smtpڑ
+		// prepare for smtp
 		GetPrivateProfileString("smtp", "server_addr", "", smtp_addr.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 		GetPrivateProfileString("smtp", "port", "", smtp_port.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 
 		if(INVALID_SOCKET == Smtp.Connect6(smtp_addr.GetBuffer(0), smtp_port.GetBuffer(0))){
 			throw "cannot establish connection";
 		}
-//============== ZbVJn ============
+//============== start smtp session ============
 		CString date;
 		CTime t = CTime::GetCurrentTime();
 		date.Format("%02d/%02d/%d %02d:%02d:%02d",t.GetDay(),t.GetMonth(),t.GetYear(),t.GetHour(),t.GetMinute(),t.GetSecond());
@@ -200,14 +195,7 @@ UINT SendMail(LPVOID pParam)
 		g_log("log-sendmail", buf);
 		df->m_send_dlg->m_status.SetWindowText(buf);
 		buf.Empty();
-/*	//-------------- helo ------------------
-		char tmpbuf[256];
-		gethostname(tmpbuf, 255);
-		CString hostname = tmpbuf;
-		if(hostname.IsEmpty())
-			hostname = "unknown";
-		command="helo "+hostname+"\r\n";
-		send_command("at HELO command");*/
+	//-------------- helo ------------------
 		if(GetPrivateProfileInt("smtp", "auth", 0, path)){
 			GetPrivateProfileString("smtp", "auth_id", "", smtp_auth_id.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 			smtp_auth_id.ReleaseBuffer();
@@ -243,7 +231,7 @@ UINT SendMail(LPVOID pParam)
 		//-------------- body ------------------
 		CString path = app->m_app_path + "\\" + df->m_account + "\\outbox";
 
-		// body̑M
+		// send body
 		command = "data\r\n";
 		send_command("at BODY command");
 		CString mail = df->m_me.GetMail(ME_GET_SEND);
@@ -281,12 +269,12 @@ UINT SendMail(LPVOID pParam)
 	//-------------- quit ----------------
 		command = "quit\r\n";
 		send_command("at QUIT command");
-		// socket
+		// close socket
 		Smtp.DisConnect();
 	}
 	catch(char* errorstr){
 		send(Smtp.m_sock, "quit\r\n", 6, 0);
-		// socket
+		// close socket
 		Smtp.DisConnect();
 		df->MessageBox(errorstr, df->m_account+" - smtp error");
 		df->EnableWindow(TRUE);
