@@ -175,11 +175,6 @@ void CSettingGeneralDlg::OnOK()
 	m_other_dlg.m_def_account.GetWindowText(buf);
 	app->WriteProfileString("DefaultMailBox", "boxname", buf);
 	// M̊ԊuݒXV
-/*	CString minute;
-	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
-	if(minute.SpanExcluding("0123456789").IsEmpty()){
-		app->WriteProfileInt("AutoFetch", "minute", atoi(minute));
-	}*/
 	CString minute;
 	m_other_dlg.m_autofetch_minute.GetWindowText(minute);
 	if(minute.SpanExcluding("0123456789").IsEmpty()){
@@ -192,11 +187,9 @@ void CSettingGeneralDlg::OnOK()
 
 	// font̕ύX
 	mf->m_pTextV->SetFontEx(m_appearance_dlg.m_tv_lf);
-//	mf->m_pTextV->SetFontColorAndLink();
 	app->WriteProfileBinary("TextViewFont", "LogFont", (LPBYTE)&m_appearance_dlg.m_tv_lf, sizeof(LOGFONT));
 	for(i=0; i < app->m_draft_array.GetSize(); i++){
 		app->m_draft_array[i]->m_pEditV->SetFontEx(m_appearance_dlg.m_ev_lf);
-//		app->m_draft_array[i]->m_pEditV->SetFontColorAndLink();
 	}
 	app->WriteProfileBinary("EditViewFont", "LogFont", (LPBYTE)&m_appearance_dlg.m_ev_lf, sizeof(LOGFONT));
 
