@@ -1,6 +1,8 @@
 /*
  * Copyright (C) 2002-2003 chik, s.hiranaka
+ * 2003-10-10 Some bug related to delete mail is removed by xken.
  * 2003-10-26 Big modification is done for owner draw and etc by xken.
+ * 2003-11-05 Some bug related to flicker drawing is removed by minamina.
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -17,6 +19,7 @@
 #include "MimeDecode.h"
 #include "lib.h"
 #include "direct.h"			// _mkdir
+#include "MemoryDC.h"
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -25,7 +28,6 @@ static char THIS_FILE[] = __FILE__;
 #endif
 
 #define SUMMARYVIEW_FILENAME _T("\\skin\\summaryview.bmp")
-//#define SUMMARYVIEW_TRANSPARENT_COLOR (RGB(128,128,128))
 #define SUMMARYVIEW_TRANSPARENT_COLOR (RGB(255,255,255))
 #define SUMMARYVIEW_ICON_READ (0)		// ǎ̃ACRԍ
 #define SUMMARYVIEW_ICON_SELECT (1)		// ĨACRԍ
@@ -34,6 +36,7 @@ static char THIS_FILE[] = __FILE__;
 #define SUMMARYVIEW_ICON_ATTACH (4)		// Yt莞̃ACRԍ
 #define SUMMARYVIEW_RESICON_W (17)
 #define SUMMARYVIEW_RESICON_H (16)
+#define SUMMARYVIEW_BACKGROUND_FILENAME _T("\\skin\\SummaryViewBk.bmp")
 
 /////////////////////////////////////////////////////////////////////////////
 // CSummaryView
@@ -64,7 +67,7 @@ CSummaryView::~CSummaryView()
 	WriteList();
 }
 
-BEGIN_MESSAGE_MAP(CSummaryView, CListView)
+BEGIN_MESSAGE_MAP(CSummaryView, CBitmapListView)
 	//{{AFX_MSG_MAP(CSummaryView)
 	ON_NOTIFY_REFLECT(LVN_GETDISPINFO, OnGetdispinfo)
 	ON_WM_CHAR()
@@ -126,7 +129,7 @@ void CSummaryView::OnInitialUpdate()
 	hWnd = lc.GetSafeHwnd();
 	dwStyle = GetWindowLong(hWnd, GWL_STYLE);
 	SetWindowLong(hWnd, GWL_STYLE, (dwStyle &~ LVS_TYPEMASK) | LVS_REPORT);
-	lc.SetExtendedStyle(LVS_EX_FULLROWSELECT);
+	lc.SetExtendedStyle(LVS_EX_FULLROWSELECT | LVS_EX_HEADERDRAGDROP);
 
 	// C[WXg̐ݒ
 	ReadIconImage();
@@ -166,6 +169,13 @@ void CSummaryView::OnInitialUpdate()
 		lc.InsertColumn(i, &lvc);
 	}
 
+	// T}[r[̃J̏Ԃ ini t@Cݒ
+	ReadIniColumnOrder();
+
+	// T}[r[̔wi摜ݒ
+	CString strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
+	SetBkImage(strBackgroundFilePath);
+
 	// Xgr[փf[^i[
 	m_index = -1;
 
@@ -314,6 +324,9 @@ void CSummaryView::SetItem(CString path)
 		app->WriteProfileInt("SummaryViewColumn", num.GetBuffer(0), lc.GetColumnWidth(i));
 	}
 
+	// T}[r[̃J̏Ԃ ini t@C֕ۑ
+	WriteIniColumnOrder();
+
 	// listview̃RKvɉĕύX
 	if(path == app->m_app_path+"\\"+current_account+"\\outbox"
 		|| path == app->m_app_path+"\\"+current_account+"\\draft")
@@ -468,6 +481,9 @@ void CSummaryView::UpdateColumn(int flag)
 		}
 	}
 
+	// T}[r[̃J̏Ԃ ini t@Cݒ
+	ReadIniColumnOrder();
+
 	int status = GetPrivateProfileInt("list", "order", 0, this->m_path+"\\folder.ini");
 	this->SetColumnOrderStatus(status);
 }
@@ -1735,6 +1751,9 @@ void CSummaryView::Clear()
 		app->WriteProfileInt("SummaryViewColumn", num.GetBuffer(0), lc.GetColumnWidth(i));
 	}
 
+	// T}[r[̃J̏Ԃ ini t@C֕ۑ
+	WriteIniColumnOrder();
+
 	// change column text for default
 	this->UpdateColumn(SMRY_COLUMN_FROM);
 
@@ -1806,79 +1825,111 @@ void CSummaryView::DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
 	bSelected = (bFocus || (GetStyle() & LVS_SHOWSELALWAYS)) && lvItem.state & LVIS_SELECTED;
 	bSelected = bSelected || (lvItem.state & LVIS_DROPHILITED);
 
-	// tHgƃJ[ݒ
-	if (!bMailUnread){
-		pFontSave = pDC->SelectObject(&m_cReadFont);
-		colText = ((bSelected) ? m_colSelectText : m_colReadText);
-		colBk = ((bSelected) ? m_colSelectBk : m_colReadBk);
-		colIconBk = m_colReadBk;
-	} else {
-		pFontSave = pDC->SelectObject(&m_cUnreadFont);
-		colText = ((bSelected) ? m_colSelectText : m_colUnreadText);
-		colBk = ((bSelected) ? m_colSelectBk : m_colUnreadBk);
-		colIconBk = m_colUnreadBk;
-	}
-	colTextSave = pDC->SetTextColor(colText);
-	colBkSave = pDC->SetBkColor(colBk);
-
 	CRect rcLabel, rcAllLabels;
 	cListCtrl.GetItemRect(nItem, rcLabel, LVIR_LABEL);
 	cListCtrl.GetItemRect(nItem, rcAllLabels, LVIR_BOUNDS);
 
+	CRect rcMemAllLabels = rcAllLabels;
+	rcMemAllLabels.OffsetRect(-rcAllLabels.left, -rcAllLabels.top);
+	CRect rcMemLabel = rcLabel;
+	rcMemLabel.OffsetRect(-rcAllLabels.left, -rcAllLabels.top);
+
+	CMemoryDC memDCBase;
+	memDCBase.Create(pDC->GetSafeHdc(), rcAllLabels.Width(), rcAllLabels.Height());
+	CDC memDC;
+	memDC.Attach(memDCBase.GetDC());
+
+	// tHgƃJ[ݒ
+	if (!bMailUnread){
+		pFontSave = memDC.SelectObject(&m_cReadFont);
+		colText = ((bSelected) ? m_colSelectText : m_colReadText);
+		colBk = ((bSelected) ? m_colSelectBk : m_colReadBk);
+		colIconBk = m_colReadBk;
+	} else {
+		pFontSave = memDC.SelectObject(&m_cUnreadFont);
+		colText = ((bSelected) ? m_colSelectText : m_colUnreadText);
+		colBk = ((bSelected) ? m_colSelectBk : m_colUnreadBk);
+		colIconBk = m_colUnreadBk;
+	}
+	if ((lvItem.state & LVIS_FOCUSED) && bFocus){
+		colTextSave = memDC.SetTextColor(colText);
+	}else if((lvItem.state & LVIS_FOCUSED)){
+		colTextSave = memDC.SetTextColor(GetSysColor(COLOR_MENUTEXT));
+	}
+	colBkSave = memDC.SetBkColor(colBk);
+	int nBkModeSave = memDC.SetBkMode(TRANSPARENT);
+
+	// s̔wiNA
+	if (bSelected || !HasBkBitmap())
+	{
+		memDC.FillRect(rcMemAllLabels, &CBrush(colBk));
+	}
+	else
+	{
+//		::BitBlt(memDC.GetSafeHdc(), 0, 0, rcAllLabels.Width(), rcAllLabels.Height(),
+//			m_bkMemDC.GetDC(), rcAllLabels.left, rcAllLabels.top, SRCCOPY);
+		CDC bkDC;
+		bkDC.Attach(m_bkMemDC.GetDC());
+		memDC.BitBlt(0, 0, rcAllLabels.Width(), rcAllLabels.Height(),
+			&bkDC, rcAllLabels.left, rcAllLabels.top, SRCCOPY);
+		bkDC.Detach();
+	}
+
+	// tH[JX``
+	if ((lvItem.state & LVIS_FOCUSED) && bFocus){
+		memDC.DrawFocusRect(rcMemAllLabels);
+	}else if((lvItem.state & LVIS_FOCUSED)){
+		memDC.FillRect(rcMemAllLabels, &CBrush(GetSysColor(COLOR_BTNFACE)));
+	}
+
 	// ACR`
 	if (bIconUsed){
 		
-		CPoint cPos(rcLabel.left, rcLabel.top);
-		pDC->FillRect(rcLabel, &CBrush(colIconBk));
+		CPoint cPos(rcMemLabel.left, rcMemLabel.top);
 		
 		// YtACR
-		if (cPos.x < rcLabel.right){
-			if (bMailAttach) m_IconImage.Draw(pDC, SUMMARYVIEW_ICON_ATTACH, cPos, ILD_TRANSPARENT);
+		if (cPos.x < rcMemLabel.right){
+			if (bMailAttach) m_IconImage.Draw(&memDC, SUMMARYVIEW_ICON_ATTACH, cPos, ILD_TRANSPARENT);
 		}
 		cPos.x += m_IconImageWidth;
 
 		// ǁIǁ폜ACR
-		if (cPos.x < rcLabel.right){
+		if (cPos.x < rcMemLabel.right){
 			int iIcon = SUMMARYVIEW_ICON_READ;
 			if (bMailUnread) iIcon = SUMMARYVIEW_ICON_UNREAD;
 			if (bMailDelete) iIcon = SUMMARYVIEW_ICON_DELETE;
 			if (bSelected) iIcon = SUMMARYVIEW_ICON_SELECT;
-			m_IconImage.Draw(pDC, iIcon, cPos, ILD_TRANSPARENT);
+			m_IconImage.Draw(&memDC, iIcon, cPos, ILD_TRANSPARENT);
 		}
-		
-		rcAllLabels.left = rcLabel.right;
-		
 	}
 
-	// s̔wiNA
-	pDC->FillRect(rcAllLabels, &CBrush(colBk));
-
 	// ŏ̃J̕`(ACRgp)
 	if (!bIconUsed){
 		int iOffsetFirst = 2;
-		pszText = MakeShortString(pDC, szBuff, (rcLabel.right-rcLabel.left), (iOffsetFirst*2));
-		rcLabel.left += iOffsetFirst;
-		rcLabel.right -= iOffsetFirst;
-		pDC->DrawText(
-			pszText, -1, rcLabel,
+		pszText = MakeShortString(&memDC, szBuff, (rcMemLabel.right-rcMemLabel.left), (iOffsetFirst*2));
+		rcMemLabel.left += iOffsetFirst;
+		rcMemLabel.right -= iOffsetFirst;
+		memDC.DrawText(
+			pszText, -1, rcMemLabel,
 			(DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_NOCLIP | DT_VCENTER)
 		);
 	}
 
 	// QԖڈȍ~̃J̕`
-	CRect rcColumn;
+	CRect rcColumn, rcMemColumn;
 	LV_COLUMN lvColumn;
 	int iOffsetOther = 6;
-	lvColumn.mask = (LVCF_FMT | LVCF_WIDTH);
+	lvColumn.mask = LVCF_FMT;
 	cListCtrl.GetItemRect(nItem, rcColumn, LVIR_LABEL);
 	for(int nColumn = 1; cListCtrl.GetColumn(nColumn, &lvColumn); nColumn++){
 		
-		rcColumn.left = rcColumn.right;
-		rcColumn.right += lvColumn.cx;
+		cListCtrl.GetSubItemRect(nItem, nColumn, LVIR_BOUNDS, rcColumn);
+		rcMemColumn = rcColumn;
+		rcMemColumn.OffsetRect(-rcAllLabels.left, -rcAllLabels.top);
 		if (cListCtrl.GetItemText(nItem, nColumn, szBuff, sizeof(szBuff)) == 0) continue;
 		
 		UINT nJustify = DT_LEFT;
-		pszText = MakeShortString(pDC, szBuff, (rcColumn.right-rcColumn.left), (iOffsetOther*2));
+		pszText = MakeShortString(&memDC, szBuff, (rcMemColumn.right-rcMemColumn.left), (iOffsetOther*2));
 		if(pszText == szBuff){
 			switch(lvColumn.fmt & LVCFMT_JUSTIFYMASK){
 			case LVCFMT_RIGHT:
@@ -1892,23 +1943,24 @@ void CSummaryView::DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct)
 			}
 		}
 		
-		rcLabel = rcColumn;
+		rcLabel = rcMemColumn;
 		rcLabel.left += iOffsetOther;
 		rcLabel.right -= iOffsetOther;
-		pDC->DrawText(
+		memDC.DrawText(
 			pszText, -1, rcLabel,
 			(nJustify | DT_SINGLELINE | DT_NOPREFIX | DT_NOCLIP | DT_VCENTER)
 		);
 		
 	}
 
-	// tH[JX``
-	if ((lvItem.state & LVIS_FOCUSED) && bFocus) pDC->DrawFocusRect(rcAllLabels);
-
 	// foCXReLXg̑߂
-	pDC->SetBkColor(colBkSave);
-	pDC->SetTextColor(colTextSave);
-	pDC->SelectObject(pFontSave);
+	memDC.SetBkColor(colBkSave);
+	memDC.SetTextColor(colTextSave);
+	memDC.SelectObject(pFontSave);
+	memDC.SetBkMode(nBkModeSave);
+
+	pDC->BitBlt(rcAllLabels.left, rcAllLabels.top, rcAllLabels.Width(), rcAllLabels.Height(),
+		&memDC, 0, 0, SRCCOPY);
 }
 
 LPCTSTR CSummaryView::MakeShortString(CDC* pDC, LPCTSTR lpszLong, int nColumnLen, int nOffset)
@@ -2117,3 +2169,40 @@ void CSummaryView::SetSelectBkColor(COLORREF colColor)
 {
 	m_colSelectBk = colColor;
 }
+
+void CSummaryView::ReadIniColumnOrder()
+{
+	// T}[r[̃J̏Ԃ ini t@Cݒ
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	int nHeaderCount = GetListCtrl().GetHeaderCtrl()->GetItemCount();
+	int* piArray = new int[nHeaderCount];
+	for (int i = 0; i < nHeaderCount; i++)
+	{
+		CString buffer;
+		buffer.Format(_T("%s%d"), _T("Order"), i);
+		piArray[i] = app->GetProfileInt(_T("SummaryViewColumn"), buffer, -1);
+	}
+	if (piArray[0] >= 0)
+	{
+		GetListCtrl().SetColumnOrderArray(nHeaderCount, piArray);
+	}
+	delete[] piArray;
+}
+
+void CSummaryView::WriteIniColumnOrder()
+{
+	// T}[r[̃J̏Ԃ ini t@C֕ۑ
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	int nHeaderCount = GetListCtrl().GetHeaderCtrl()->GetItemCount();
+	int* piArray = new int[nHeaderCount];
+	if (GetListCtrl().GetColumnOrderArray(piArray) != 0)
+	{
+		for (int i = 0; i < nHeaderCount; i++)
+		{
+			CString buffer;
+			buffer.Format(_T("%s%d"), _T("Order"), i);
+			app->WriteProfileInt(_T("SummaryViewColumn"), buffer, piArray[i]);
+		}
+	}
+	delete[] piArray;
+}
