@@ -9,6 +9,7 @@
 #include <afxcview.h>
 #include <afxtempl.h>	// CArrayev[gNXɕKv
 #include "ListStackStruct.h"
+#include "BitmapListView.h"
 
 #define SMRY_COLUMN_FROM (0)
 #define SMRY_COLUMN_TO (1)
@@ -18,7 +19,7 @@
 /////////////////////////////////////////////////////////////////////////////
 // CSummaryView r[
 
-class CSummaryView : public CListView
+class CSummaryView : public CBitmapListView
 {
 protected:
 	CSummaryView();	// IɎgpveNg RXgN^
@@ -80,6 +81,8 @@ public:
 	void WriteList(); // write out m_array_list into list file
 
 public:
+	void ReadIniColumnOrder();
+	void WriteIniColumnOrder();
 	void ReadIconImage(void);
 	void UpdateSummaryView(void);
 	void SetIconUsed(bool bUsed);
