@@ -18,11 +18,12 @@
 #include <Shlwapi.h> // StrStrI vWFNg̐ݒ̃N"Shlwapi.lib"ǉ
 #include "quoted-printable.h"
 #include "base64.h"
-//#include "_regex.h"
 #include "lib.h"
 #include "direct.h"			// _mkdir
 #include "Gpg.h"
 
+#include "Template.h"
+
 #ifdef _DEBUG
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -61,7 +62,7 @@ END_MESSAGE_MAP()
 // CTextView `
 
 void CTextView::OnDraw(CDC* pDC)
-{
+{	
 	CDocument* pDoc = GetDocument();
 }
 
@@ -87,7 +88,6 @@ void CTextView::OnInitialUpdate()
 {
 	CRichEditView::OnInitialUpdate();
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
-
 	CRichEditCtrl& r = GetRichEditCtrl();
 
  /*   HWND hwnd = r.m_hWnd;
@@ -103,7 +103,6 @@ void CTextView::OnInitialUpdate()
 		::CopyMemory(&lf, pData, sizeof(LOGFONT));
 		delete [] pData; 
 	}else{
-//		::GetObject(GetStockObject(DEFAULT_GUI_FONT), sizeof(LOGFONT), &lf);
 		lf.lfHeight = -16;
 		lf.lfWidth = 0;
 		lf.lfEscapement = 0;
@@ -129,10 +128,12 @@ void CTextView::OnInitialUpdate()
 
 	this->SetFontColorAndLink();
 
-//	if(ݒŐ܂ԂȂɂȂĂȉs)
-//	m_nWordWrap = WrapNone;
-//	WrapChanged(); // ܂ԂȂ
-//	r.SetOptions(ECOOP_OR,ECO_AUTOHSCROLL);
+	// prepare for header template
+	if(g_is_there(app->m_app_path+"\\template\\header.htmpl")){
+		g_file2cstring(app->m_app_path+"\\template\\header.htmpl", this->m_header_template);
+	}else{
+		this->m_header_template = DEF_HEADER_TEMPLATE;
+	}
 }
 
 void CTextView::Font()
@@ -334,10 +335,13 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 
 void CTextView::DisplayPart(int part)
 {
-//	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CStringArray body;
 	CString message;
 	CString header;
+	CString tmp;
+	CTemplate tmpl;
 
 	m_current_part = part;
 	m_md.GetBody(part, body);
@@ -386,35 +390,24 @@ void CTextView::DisplayPart(int part)
 			message.Format("Ytt@C\r\n%s", m_md.GetFileName(part));
 		}
 	}
-
 	m_body = message;
 
-	// \pwb_̏
-	// prepare for heaer info displayed on textview.
-	if(!m_md.m_hi.GetTo().IsEmpty())
-		header += "To: "+m_md.m_hi.GetTo()+"\r\n";
-	if(!m_md.m_hi.GetCc().IsEmpty())
-		header += "Cc: "+m_md.m_hi.GetCc()+"\r\n";
-	if(!m_md.m_hi.GetBcc().IsEmpty())
-		header += "Bcc: "+m_md.m_hi.GetBcc()+"\r\n";
-	if(!m_md.m_hi.GetFrom().IsEmpty())
-		header += "From: "+m_md.m_hi.GetFrom()+"\r\n";
-	if(!m_md.m_hi.GetSubject().IsEmpty())
-		header += "Subject: "+m_md.m_hi.GetSubject()+"\r\n";
-	if(!m_md.m_hi.GetDate().IsEmpty())
-		header += "Date: "+m_md.m_hi.GetDate()+"\r\n";
-	if(!m_md.m_hi.GetReplyTo().IsEmpty())
-		header += "Reply-To: "+m_md.m_hi.GetReplyTo()+"\r\n";
-	if(!m_md.m_hi.GetXmailer().IsEmpty())
-		header += "X-Mailer: "+m_md.m_hi.GetXmailer()+"\r\n";
-
+	// prepare for header info displayed on textview of headerview.
+	header = tmpl.GetString(&m_md, this->m_header_template);
+	header.TrimRight();
 	m_header = header;
 
-	message = header+"\r\n"+message;
+	if(!app->GetProfileInt("Customize", "HeaderView", 1)){
+		message = header+"\r\n\r\n"+message;
+	}
 	m_text = message;
 
 	this->SetWindowText("");
 	this->SetWindowText(message);
+	if(app->GetProfileInt("Customize", "HeaderView", 1)){
+		header.TrimRight();
+		mf->m_pHeadV->SetHeaderText(header);
+	}
 
 /*	CHARFORMAT cf;
 	GetRichEditCtrl().SetSel(0, header.GetLength());
@@ -698,11 +691,9 @@ void CTextView::OnSetFocus(CWnd* pOldWnd)
 
 void CTextView::SetFontEx(LOGFONT &lf)
 {
-	CRichEditCtrl &r = GetRichEditCtrl();
-
 	m_font.DeleteObject();
 	if(m_font.CreateFontIndirect(&lf))
-		r.SetFont(&m_font);
+		GetRichEditCtrl().SetFont(&m_font);
 	this->SetFontColorAndLink();
 }
 
@@ -711,14 +702,13 @@ void CTextView::SetFontColorAndLink()
 	CRichEditCtrl &r = GetRichEditCtrl();
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 
-	// clickable url Lɂ
+	// enable clickable url
 	long lENM = r.GetEventMask();
 	lENM |= ENM_LINK;
 	r.SetEventMask(lENM);
-	BOOL bEnable = 1;
-	::SendMessage(m_hWnd, EM_AUTOURLDETECT, bEnable, 0);
+	::SendMessage(m_hWnd, EM_AUTOURLDETECT, TRUE, 0);
 
-	// ̑ݒ
+	// set attribute of charactor
 	CHARFORMAT2 cf;
 	r.GetDefaultCharFormat(cf);
 	cf.dwMask = CFM_COLOR | CFM_PROTECTED | CFM_FACE | CFM_SIZE | CFM_CHARSET | CFM_SUBSCRIPT;
@@ -732,30 +722,24 @@ void CTextView::SetFontColorAndLink()
 //	r.SendMessage(EM_SETCHARFORMAT,(WPARAM)SCF_ALL,(LPARAM)&cf);
 	r.SetSel(0, -1);
 	r.SetSelectionCharFormat(cf);
-
-	CString mail;
-	r.GetWindowText(mail);
-	r.SetSel(0, mail.Find("\r\n\r\n")+2);
-	r.GetSelectionCharFormat(cf);
-	cf.dwMask = CFM_COLOR | CFM_BACKCOLOR;
-	cf.crTextColor = RGB(
-		app->GetProfileInt("TextViewHdColor", "TxtColorR", DEF_HEADER_INFO_COLOR_R),
-		app->GetProfileInt("TextViewHdColor", "TxtColorG", DEF_HEADER_INFO_COLOR_G),
-		app->GetProfileInt("TextViewHdColor", "TxtColorB", DEF_HEADER_INFO_COLOR_B));
-	r.SetSelectionCharFormat(cf);
 	r.HideSelection(TRUE, FALSE);
 	r.SetSel(0, 0);
 
-	// sԂ𒲐
-//	PARAFORMAT2 pf;
-//	pf.cbSize = sizeof(pf);
-//	pf.dwMask = PFM_LINESPACING | PFM_SPACEAFTER;
-//	pf.dySpaceAfter = 0;
-//	pf.bLineSpacingRule = 4;
-//	pf.dyLineSpacing = 210;
-//	r.SetSel(0,-1);
-//	r.SendMessage(EM_SETPARAFORMAT,0,(LPARAM)&pf);
-//	r.SetSel(0,0);
+	// if header view is not active, set header info color.
+	if(!app->GetProfileInt("Customize", "HeaderView", 1)){
+		CString mail;
+		r.GetWindowText(mail);
+		r.SetSel(0, mail.Find("\r\n\r\n")+2);
+		r.GetSelectionCharFormat(cf);
+		cf.dwMask = CFM_COLOR | CFM_BACKCOLOR;
+		cf.crTextColor = RGB(
+			app->GetProfileInt("TextViewHdColor", "TxtColorR", DEF_HEADER_INFO_COLOR_R),
+			app->GetProfileInt("TextViewHdColor", "TxtColorG", DEF_HEADER_INFO_COLOR_G),
+			app->GetProfileInt("TextViewHdColor", "TxtColorB", DEF_HEADER_INFO_COLOR_B));
+		r.SetSelectionCharFormat(cf);
+		r.HideSelection(TRUE, FALSE);
+		r.SetSel(0, 0);
+	}
 }
 
 void CTextView::ReDisplay()
