@@ -231,6 +231,8 @@ public:
 
 	// ClassWizard z֐̃I[o[Ch𐶐܂B
 	//{{AFX_VIRTUAL(CAboutDlg)
+	public:
+	virtual BOOL OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo);
 	protected:
 	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV ̃T|[g
 	//}}AFX_VIRTUAL
@@ -364,3 +366,10 @@ BOOL CAboutDlg::OnInitDialog()
 	return TRUE;  // Rg[ɃtH[JXݒ肵ȂƂA߂l TRUE ƂȂ܂
 	              // O: OCX vpeB y[W̖߂l FALSE ƂȂ܂
 }
+
+BOOL CAboutDlg::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo) 
+{
+	// TODO: ̈ʒuɌŗL̏ǉ邩A܂͊{NXĂяoĂ
+	
+	return CDialog::OnCmdMsg(nID, nCode, pExtra, pHandlerInfo);
+}
